﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Diagnostics;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Input;
using XamTabControl_sample.Model;

namespace XamTabControl_sample
{
    public class ViewModel : INotifyPropertyChanged
    {
        private ObservableCollection<Data> _items;
        Random rnd = new Random();
        
        public ViewModel()
        {
            if (null == _items)
                _items = new ObservableCollection<Data>();

            _items = Data.GetData(100, 1, 10);
        }


        public ICommand AddItems
        {
            get
            {
                return new RelayCommand<object>(
                    new Action<object>(
                        (obj) =>
                        {
                            _items.Add(new Data()
                            {
                                Label = "New Item " + rnd.Next(0, 9),
                                High = rnd.Next(1, 100),
                                Value = rnd.Next(1,100)
                            });
                        }
                ));
            }
        }

        public ObservableCollection<Data> Items
        {
            get { return _items; }
            set
            {
                _items = Items;
                PropChanged("Label");
            }
        }

        public event PropertyChangedEventHandler PropertyChanged;

        public void PropChanged(string name)
        {
            if (PropertyChanged != null)
                PropertyChanged(this, new PropertyChangedEventArgs(name));
        }
    }


    public class RelayCommand<T> : ICommand
    {

        #region Declarations

        readonly Predicate<T> _canExecute;
        readonly Action<T> _execute;

        #endregion

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="RelayCommand&lt;T&gt;"/> class and 
        /// the command can always be executed.
        /// </summary>
        /// <param name="execute">The execution logic.</param>
        public RelayCommand(Action<T> execute)
            : this(execute, null)
        {
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="RelayCommand&lt;T&gt;"/> class.
        /// </summary>
        /// <param name="execute">The execution logic.</param>
        /// <param name="canExecute">The execution status logic.</param>
        public RelayCommand(Action<T> execute, Predicate<T> canExecute)
        {

            if (execute == null)
                throw new ArgumentNullException("execute");
            _execute = execute;
            _canExecute = canExecute;
        }

        #endregion

        #region ICommand Members

        public event EventHandler CanExecuteChanged
        {
            add
            {

                if (_canExecute != null)
                    CommandManager.RequerySuggested += value;
            }
            remove
            {

                if (_canExecute != null)
                    CommandManager.RequerySuggested -= value;
            }
        }



        [DebuggerStepThrough]
        public virtual Boolean CanExecute(Object parameter)
        {
            return _canExecute == null ? true : _canExecute((T)parameter);
        }

        public virtual void Execute(Object parameter)
        {
            _execute((T)parameter);
        }



        #endregion
    }
}
