﻿using System;
using System.Windows.Interactivity;
using Infragistics.Windows.DataPresenter;
using Infragistics.Windows.DataPresenter.Events;

namespace RefreshIssue
{
    public class XamDataGridSummaryBehavior : Behavior<XamDataGrid>
    {
        protected override void OnAttached()
        {
            base.OnAttached();

            try
            {
                AssociatedObject.FieldLayoutInitialized += OnFieldLayoutInitialized;
            }
            catch (Exception ex)
            {
                
            }
        }

        private void OnFieldLayoutInitialized(object sender, FieldLayoutInitializedEventArgs e)
        {
            var fieldLayout = e.FieldLayout;
            foreach (var field in fieldLayout.Fields)
            {
                if (field.DataType == typeof(short) || field.DataType == typeof(int) || field.DataType == typeof(long) || 
                    field.DataType == typeof(short?) || field.DataType == typeof(int?) || field.DataType == typeof(long?) ||
                    field.DataType == typeof(float) || field.DataType == typeof(double) || field.DataType == typeof(decimal) || 
                    field.DataType == typeof(float?) || field.DataType == typeof(double?) || field.DataType == typeof(decimal?))
                {
                    var summaryDefinition = new SummaryDefinition { Calculator = SummaryCalculator.Sum, SourceFieldName = field.Name };
                    if (field.DataType == typeof(float) || field.DataType == typeof(double) ||
                        field.DataType == typeof(decimal) ||
                        field.DataType == typeof(float?) || field.DataType == typeof(double?) ||
                        field.DataType == typeof(decimal?))
                    {
                        summaryDefinition.StringFormat = "{0:0.00}";
                    }
                    else
                    {
                        summaryDefinition.StringFormat = "{0:0}";
                    }

                    fieldLayout.SummaryDefinitions.Add(summaryDefinition);
                }
            }

            fieldLayout.FieldSettings.SummaryUIType = SummaryUIType.MultiSelectForNumericsOnly;
        }

        protected override void OnDetaching()
        {
            try
            {
                AssociatedObject.FieldLayoutInitialized -= OnFieldLayoutInitialized;
            }
            catch (Exception ex)
            {
                
            }
        }
    }
}
